Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(846)

Unified Diff: third_party/WebKit/Source/modules/worklet/WorkletGlobalScope.h

Issue 1684303002: Add a basic version of Worklet#import. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix non-oilpan build. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/worklet/WorkletGlobalScope.h
diff --git a/third_party/WebKit/Source/modules/worklet/WorkletGlobalScope.h b/third_party/WebKit/Source/modules/worklet/WorkletGlobalScope.h
index e26977f54bf842df352d9ffb99f455d56dbe8c01..a9498de73fea55ab74e1ef4ac85acbdb235d4328 100644
--- a/third_party/WebKit/Source/modules/worklet/WorkletGlobalScope.h
+++ b/third_party/WebKit/Source/modules/worklet/WorkletGlobalScope.h
@@ -28,9 +28,9 @@ public:
using RefCounted<WorkletGlobalScope>::deref;
#endif
- // The url and userAgent arguments are inherited from the parent
- // ExecutionContext for Worklets.
- static PassRefPtrWillBeRawPtr<WorkletGlobalScope> create(const KURL&, const String& userAgent, v8::Isolate*);
+ // The url, userAgent and securityOrigin arguments are inherited from the
+ // parent ExecutionContext for Worklets.
+ static PassRefPtrWillBeRawPtr<WorkletGlobalScope> create(const KURL&, const String& userAgent, PassRefPtr<SecurityOrigin>, v8::Isolate*);
~WorkletGlobalScope() override;
bool isWorkletGlobalScope() const final { return true; }
@@ -74,7 +74,7 @@ private:
void derefExecutionContext() final { deref(); }
#endif
- WorkletGlobalScope(const KURL&, const String& userAgent, v8::Isolate*);
+ WorkletGlobalScope(const KURL&, const String& userAgent, PassRefPtr<SecurityOrigin>, v8::Isolate*);
const KURL& virtualURL() const final { return m_url; }
KURL virtualCompleteURL(const String&) const final;

Powered by Google App Engine
This is Rietveld 408576698